@@ -13,10 +13,16 @@ token_nav_string <- function(tokens, meta, doc_col, token_nav, top_nav=NULL, thr
     utok = stats::na.omit(unique(tokens[,c(doc_col,token_nav)]))
     utok = split(utok[[token_nav]], utok[[doc_col]])
   }
+
+  #browser()
   ids = names(utok)
 
-  navstring = sapply(utok, function(x) stats::na.omit(sprintf('<tag>%s</tag>', x)), simplify = F)
-  navstring = stringi::stri_paste_list(navstring, sep = ', ')
+  #ids
+  #navstring
+
+  navstring = sapply(utok, function(x) paste(stats::na.omit(sprintf('<tag>%s</tag>', x)), collapse=', '), simplify = F)
+  #navstring = stringi::stri_paste_list(navstring, sep = ', ')
+  #navstring
 
   out = rep('', nrow(meta))
   out[match(ids, meta[[doc_col]])] = navstring
